@@ -20,6 +20,10 @@ pub enum DirectUrl {
     /// {"archive_info": {"hash": "sha256=75909db2664838d015e3d9139004ee16711748a52c8f336b52882266540215d8", "hashes": {"sha256": "75909db2664838d015e3d9139004ee16711748a52c8f336b52882266540215d8"}}, "url": "https://files.pythonhosted.org/packages/b8/8b/31273bf66016be6ad22bb7345c37ff350276cfd46e389a0c2ac5da9d9073/wheel-0.41.2-py3-none-any.whl"}
     /// ```
     ArchiveUrl {
+        /// The URL without parsed information (such as the Git revision or subdirectory).
+        ///
+        /// For example, for `pip install git+https://github.com/tqdm/tqdm@cc372d09dcd5a5eabdc6ed4cf365bdb0be004d44#subdirectory=.`,
+        /// the URL is `https://github.com/tqdm/tqdm`.
         url: String,
         archive_info: ArchiveInfo,
         #[serde(skip_serializing_if = "Option::is_none")]
@@ -75,10 +79,10 @@ pub enum VcsKind {
 impl std::fmt::Display for VcsKind {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
-            VcsKind::Git => write!(f, "git"),
-            VcsKind::Hg => write!(f, "hg"),
-            VcsKind::Bzr => write!(f, "bzr"),
-            VcsKind::Svn => write!(f, "svn"),
+            Self::Git => write!(f, "git"),
+            Self::Hg => write!(f, "hg"),
+            Self::Bzr => write!(f, "bzr"),
+            Self::Svn => write!(f, "svn"),
         }
     }
 }
@@ -88,13 +92,13 @@ impl TryFrom<&DirectUrl> for Url {
 
     fn try_from(value: &DirectUrl) -> Result<Self, Self::Error> {
         match value {
-            DirectUrl::LocalDirectory { url, .. } => Url::parse(url),
+            DirectUrl::LocalDirectory { url, .. } => Self::parse(url),
             DirectUrl::ArchiveUrl {
                 url,
                 subdirectory,
                 archive_info: _,
             } => {
-                let mut url = Url::parse(url)?;
+                let mut url = Self::parse(url)?;
                 if let Some(subdirectory) = subdirectory {
                     url.set_fragment(Some(&format!("subdirectory={}", subdirectory.display())));
                 }
@@ -105,7 +109,7 @@ impl TryFrom<&DirectUrl> for Url {
                 vcs_info,
                 subdirectory,
             } => {
-                let mut url = Url::parse(&format!("{}+{}", vcs_info.vcs, url))?;
+                let mut url = Self::parse(&format!("{}+{}", vcs_info.vcs, url))?;
                 if let Some(commit_id) = &vcs_info.commit_id {
                     url.set_path(&format!("{}@{commit_id}", url.path()));
                 } else if let Some(requested_revision) = &vcs_info.requested_revision {
