@@ -3,6 +3,8 @@ pub use build_options::*;
 pub use concurrency::*;
 pub use config_settings::*;
 pub use constraints::*;
+pub use extras::*;
+pub use hash::*;
 pub use name_specifiers::*;
 pub use overrides::*;
 pub use package_options::*;
@@ -14,6 +16,8 @@ mod build_options;
 mod concurrency;
 mod config_settings;
 mod constraints;
+mod extras;
+mod hash;
 mod name_specifiers;
 mod overrides;
 mod package_options;
