@@ -1,5 +1,5 @@
+use std::collections::hash_map::Entry;
 use std::str::FromStr;
-use std::sync::Arc;
 
 use rustc_hash::FxHashMap;
 use tracing::trace;
@@ -27,16 +27,6 @@ pub struct Preference {
 }
 
 impl Preference {
-    /// Create a simple [`Preference`] with no hashes.
-    pub fn simple(name: PackageName, version: Version) -> Self {
-        Self {
-            name,
-            version,
-            marker: None,
-            hashes: Vec::new(),
-        }
-    }
-
     /// Create a [`Preference`] from a [`RequirementEntry`].
     pub fn from_entry(entry: RequirementEntry) -> Result<Option<Self>, PreferenceError> {
         let RequirementsTxtRequirement::Named(requirement) = entry.requirement else {
@@ -45,17 +35,17 @@ impl Preference {
 
         let Some(VersionOrUrl::VersionSpecifier(specifier)) = requirement.version_or_url.as_ref()
         else {
-            trace!("Excluding {requirement} from preferences due to non-version specifier.");
+            trace!("Excluding {requirement} from preferences due to non-version specifier");
             return Ok(None);
         };
 
         let [specifier] = specifier.as_ref() else {
-            trace!("Excluding {requirement} from preferences due to multiple version specifiers.");
+            trace!("Excluding {requirement} from preferences due to multiple version specifiers");
             return Ok(None);
         };
 
         if *specifier.operator() != Operator::Equal {
-            trace!("Excluding {requirement} from preferences due to inexact version specifier.");
+            trace!("Excluding {requirement} from preferences due to inexact version specifier");
             return Ok(None);
         }
 
@@ -108,8 +98,8 @@ impl Preference {
 }
 
 /// A set of pinned packages that should be preserved during resolution, if possible.
-#[derive(Debug, Clone)]
-pub(crate) struct Preferences(Arc<FxHashMap<PackageName, Pin>>);
+#[derive(Debug, Clone, Default)]
+pub struct Preferences(FxHashMap<PackageName, Pin>);
 
 impl Preferences {
     /// Create a map of pinned packages from an iterator of [`Preference`] entries.
@@ -117,7 +107,7 @@ impl Preferences {
     ///
     /// The provided [`MarkerEnvironment`] will be used to filter  the preferences
     /// to an applicable subset.
-    pub(crate) fn from_iter<PreferenceIterator: IntoIterator<Item = Preference>>(
+    pub fn from_iter<PreferenceIterator: IntoIterator<Item = Preference>>(
         preferences: PreferenceIterator,
         markers: Option<&MarkerEnvironment>,
     ) -> Self {
@@ -138,13 +128,23 @@ impl Preferences {
                         },
                     ))
                 } else {
-                    trace!("Excluding {preference} from preferences due to unmatched markers.");
+                    trace!("Excluding {preference} from preferences due to unmatched markers");
                     None
                 }
             })
             .collect();
 
-        Self(Arc::new(preferences))
+        Self(preferences)
+    }
+
+    /// Return the [`Entry`] for a package in the preferences.
+    pub fn entry(&mut self, package_name: PackageName) -> Entry<PackageName, Pin> {
+        self.0.entry(package_name)
+    }
+
+    /// Returns an iterator over the preferences.
+    pub fn iter(&self) -> impl Iterator<Item = (&PackageName, &Version)> {
+        self.0.iter().map(|(name, pin)| (name, pin.version()))
     }
 
     /// Return the pinned version for a package, if any.
@@ -173,7 +173,7 @@ impl std::fmt::Display for Preference {
 
 /// The pinned data associated with a package in a locked `requirements.txt` file (e.g., `flask==1.2.3`).
 #[derive(Debug, Clone)]
-struct Pin {
+pub struct Pin {
     version: Version,
     hashes: Vec<HashDigest>,
 }
@@ -189,3 +189,12 @@ impl Pin {
         &self.hashes
     }
 }
+
+impl From<Version> for Pin {
+    fn from(version: Version) -> Self {
+        Self {
+            version,
+            hashes: Vec::new(),
+        }
+    }
+}
