@@ -5,13 +5,9 @@ use uv_normalize::PackageName;
 
 use crate::{DependencyMode, Manifest};
 
-#[derive(Debug, Default, Clone, Copy, PartialEq, Eq)]
+#[derive(Debug, Default, Clone, Copy, PartialEq, Eq, serde::Deserialize, serde::Serialize)]
+#[serde(deny_unknown_fields, rename_all = "kebab-case")]
 #[cfg_attr(feature = "clap", derive(clap::ValueEnum))]
-#[cfg_attr(feature = "serde", derive(serde::Deserialize))]
-#[cfg_attr(
-    feature = "serde",
-    serde(deny_unknown_fields, rename_all = "kebab-case")
-)]
 #[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
 pub enum ResolutionMode {
     /// Resolve the highest compatible version of each package.
@@ -24,6 +20,16 @@ pub enum ResolutionMode {
     LowestDirect,
 }
 
+impl std::fmt::Display for ResolutionMode {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Self::Highest => write!(f, "highest"),
+            Self::Lowest => write!(f, "lowest"),
+            Self::LowestDirect => write!(f, "lowest-direct"),
+        }
+    }
+}
+
 /// Like [`ResolutionMode`], but with any additional information required to select a candidate,
 /// like the set of direct dependencies.
 #[derive(Debug, Clone)]
@@ -41,7 +47,7 @@ impl ResolutionStrategy {
     pub(crate) fn from_mode(
         mode: ResolutionMode,
         manifest: &Manifest,
-        markers: &MarkerEnvironment,
+        markers: Option<&MarkerEnvironment>,
         dependencies: DependencyMode,
     ) -> Self {
         match mode {
@@ -50,7 +56,7 @@ impl ResolutionStrategy {
             ResolutionMode::LowestDirect => Self::LowestDirect(
                 manifest
                     .user_requirements(markers, dependencies)
-                    .map(|requirement| requirement.name.clone())
+                    .map(|requirement| (*requirement).clone())
                     .collect(),
             ),
         }
