@@ -4,8 +4,8 @@ use std::path::PathBuf;
 use distribution_types::IndexUrl;
 use install_wheel_rs::linker::LinkMode;
 use uv_configuration::{ConfigSettings, IndexStrategy, KeyringProviderType, TargetTriple};
+use uv_python::{PythonFetch, PythonPreference, PythonVersion};
 use uv_resolver::{AnnotationStyle, ExcludeNewer, PreReleaseMode, ResolutionMode};
-use uv_toolchain::{PythonVersion, ToolchainFetch, ToolchainPreference};
 
 use crate::{FilesystemOptions, PipOptions};
 
@@ -69,8 +69,8 @@ impl_combine_or!(PythonVersion);
 impl_combine_or!(ResolutionMode);
 impl_combine_or!(String);
 impl_combine_or!(TargetTriple);
-impl_combine_or!(ToolchainPreference);
-impl_combine_or!(ToolchainFetch);
+impl_combine_or!(PythonPreference);
+impl_combine_or!(PythonFetch);
 impl_combine_or!(bool);
 
 impl<T> Combine for Option<Vec<T>> {
