@@ -40,6 +40,7 @@ pub(crate) async fn pip_install(
     requirements: &[RequirementsSource],
     constraints: &[RequirementsSource],
     overrides: &[RequirementsSource],
+    constraints_from_workspace: Vec<Requirement>,
     overrides_from_workspace: Vec<Requirement>,
     extras: &ExtrasSpecification,
     resolution_mode: ResolutionMode,
@@ -104,6 +105,12 @@ pub(crate) async fn pip_install(
     )
     .await?;
 
+    let constraints: Vec<Requirement> = constraints
+        .iter()
+        .cloned()
+        .chain(constraints_from_workspace.into_iter())
+        .collect();
+
     let overrides: Vec<UnresolvedRequirementSpecification> = overrides
         .iter()
         .cloned()
