@@ -3,11 +3,10 @@ use std::str::FromStr;
 
 use anyhow::{bail, Result};
 use owo_colors::OwoColorize;
-
 use tracing::debug;
+
 use uv_cache::Cache;
 use uv_configuration::PreviewMode;
-use uv_distribution::VirtualProject;
 use uv_fs::Simplified;
 use uv_python::{
     request_from_version_file, requests_from_version_file, write_version_file,
@@ -15,6 +14,7 @@ use uv_python::{
     PYTHON_VERSION_FILENAME,
 };
 use uv_warnings::warn_user_once;
+use uv_workspace::{DiscoveryOptions, VirtualProject};
 
 use crate::commands::{project::find_requires_python, ExitStatus};
 use crate::printer::Printer;
@@ -33,12 +33,17 @@ pub(crate) async fn pin(
         warn_user_once!("`uv python pin` is experimental and may change without warning");
     }
 
-    let virtual_project = match VirtualProject::discover(&std::env::current_dir()?, None).await {
-        Ok(virtual_project) if !isolated => Some(virtual_project),
-        Ok(_) => None,
-        Err(err) => {
-            debug!("Failed to discover virtual project: {err}");
-            None
+    let virtual_project = if isolated {
+        None
+    } else {
+        match VirtualProject::discover(&std::env::current_dir()?, &DiscoveryOptions::default())
+            .await
+        {
+            Ok(virtual_project) => Some(virtual_project),
+            Err(err) => {
+                debug!("Failed to discover virtual project: {err}");
+                None
+            }
         }
     };
 
@@ -271,7 +276,7 @@ fn assert_pin_compatible_with_project(pin: &Pin, virtual_project: &VirtualProjec
     };
 
     Err(anyhow::anyhow!(
-        "The {given} Python version `{}`{resolved} is incompatible with the {} `Requires-Python` requirement of `{}`.",
+        "The {given} Python version `{}`{resolved} is incompatible with the {} `requires-python` value of `{}`.",
         pin.request.to_canonical_string(),
         project_type,
         requires_python
