@@ -153,6 +153,7 @@ impl CacheSettings {
 pub(crate) struct InitSettings {
     pub(crate) path: Option<String>,
     pub(crate) name: Option<PackageName>,
+    pub(crate) r#virtual: bool,
     pub(crate) no_readme: bool,
     pub(crate) python: Option<String>,
 }
@@ -164,6 +165,7 @@ impl InitSettings {
         let InitArgs {
             path,
             name,
+            r#virtual,
             no_readme,
             python,
         } = args;
@@ -171,6 +173,7 @@ impl InitSettings {
         Self {
             path,
             name,
+            r#virtual,
             no_readme,
             python,
         }
@@ -248,6 +251,7 @@ pub(crate) struct ToolRunSettings {
     pub(crate) command: ExternalCommand,
     pub(crate) from: Option<String>,
     pub(crate) with: Vec<String>,
+    pub(crate) with_requirements: Vec<PathBuf>,
     pub(crate) python: Option<String>,
     pub(crate) refresh: Refresh,
     pub(crate) settings: ResolverInstallerSettings,
@@ -261,6 +265,7 @@ impl ToolRunSettings {
             command,
             from,
             with,
+            with_requirements,
             installer,
             build,
             refresh,
@@ -271,6 +276,10 @@ impl ToolRunSettings {
             command,
             from,
             with,
+            with_requirements: with_requirements
+                .into_iter()
+                .filter_map(Maybe::into_option)
+                .collect(),
             python,
             refresh: Refresh::from(refresh),
             settings: ResolverInstallerSettings::combine(
@@ -288,6 +297,7 @@ pub(crate) struct ToolInstallSettings {
     pub(crate) package: String,
     pub(crate) from: Option<String>,
     pub(crate) with: Vec<String>,
+    pub(crate) with_requirements: Vec<PathBuf>,
     pub(crate) python: Option<String>,
     pub(crate) refresh: Refresh,
     pub(crate) settings: ResolverInstallerSettings,
@@ -302,6 +312,7 @@ impl ToolInstallSettings {
             package,
             from,
             with,
+            with_requirements,
             installer,
             force,
             build,
@@ -313,6 +324,10 @@ impl ToolInstallSettings {
             package,
             from,
             with,
+            with_requirements: with_requirements
+                .into_iter()
+                .filter_map(Maybe::into_option)
+                .collect(),
             python,
             force,
             refresh: Refresh::from(refresh),
@@ -1466,7 +1481,7 @@ pub(crate) struct ResolverSettings {
     pub(crate) build_options: BuildOptions,
 }
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Copy)]
 pub(crate) struct ResolverSettingsRef<'a> {
     pub(crate) index_locations: &'a IndexLocations,
     pub(crate) index_strategy: IndexStrategy,
